@@ -78,26 +78,83 @@ su_m_factor_by_gamm4 <- gamm4(y ~ fac + s(x2, by = fac) + s(x0),
 su_m_factor_by_bam <- bam(y ~ fac + s(x2, by = fac) + s(x0), data = su_eg4)
 
 su_m_factor_by_x2 <- gam(y ~ fac + s(x2, by = fac),
-                         data = su_eg4,
-                         method = "REML")
+  data = su_eg4,
+  method = "REML")
+
+if (packageVersion("mgcv") >= "1.8.41") {
+  m_sz <- gam(y ~ s(x2) + s(fac, x2, bs = "sz") + s(x0),
+    data = su_eg4, method = "REML")
+
+  # two factor sz smooth example from ?smooth.construct.sz.smooth.spec
+  ## Example involving 2 factors
+  two_factor_sz_example <- function(seed = NULL) {
+    ## sort out the seed
+    if (!exists(".Random.seed", envir = .GlobalEnv, inherits = FALSE)) {
+      runif(1)
+    }
+    if (is.null(seed)) {
+      RNGstate <- get(".Random.seed", envir = .GlobalEnv)
+    } else {
+      R.seed <- get(".Random.seed", envir = .GlobalEnv)
+      set.seed(seed)
+      RNGstate <- structure(seed, kind = as.list(RNGkind()))
+      on.exit(assign(".Random.seed", R.seed, envir = .GlobalEnv))
+    }
+    f1 <- function(x2) 2 * sin(pi * x2)
+    f2 <- function(x2) exp(2 * x2) - 3.75887
+    f3 <- function(x2) 0.2 * x2^11 * (10 * (1 - x2))^6 + 10 * (10 * x2)^3 *
+      (1 - x2)^10
+
+    n <- 600
+    x <- runif(n)
+    f1 <- factor(sample(c("a", "b", "c"), n, replace = TRUE))
+    f2 <- factor(sample(c("foo", "bar"), n, replace = TRUE))
+
+    mu <- f3(x)
+    for (i in 1:3) mu <- mu + exp(2 * (2 - i) * x) * (f1 == levels(f1)[i])
+    for (i in 1:2) mu <- mu + 10 * i * x * (1 - x) * (f2 == levels(f2)[i])
+    y <- mu + rnorm(n)
+    dat <- data.frame(y = y, x = x, f1 = f1, f2 = f2)
+    dat
+  }
+  su_eg_sz_2_factor <- two_factor_sz_example(seed = 42)
+  # using bam as it is so much faster
+  m_sz_2f <- bam(y ~ s(x) + s(f1, x, bs = "sz") + s(f2, x, bs = "sz") +
+    s(f1, f2, x, bs = "sz", id = 1),
+  data = su_eg_sz_2_factor, method = "fREML")
+}
+
+su_eg2_by <- su_eg2 %>%
+  mutate(y = y + y^2 + y^3) %>%
+  bind_rows(su_eg2) %>%
+  mutate(fac = factor(rep(c("A", "B"), each = nrow(su_eg2))))
+su_m_bivar_by_fac <- gam(y ~ fac + s(x, z, k = 40, by = fac),
+                  data = su_eg2_by,
+                  method = "REML")
 
 su_gamm_univar_4 <- gamm(y ~ s(x0) + s(x1) + s(x2) + s(x3),
                          data = su_eg1,
                          method = "REML")
 
 m_1_smooth <- gam(y ~ s(x0), data = quick_eg1, method = "REML")
+
+m_1_smooth_offset <- gam(y ~ s(x0) + offset(log(off)),
+  data = quick_eg1 |> mutate(off = 2), method = "REML")
+
 m_gam <- su_m_univar_4
-# m_gam    <- gam(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = su_eg1,
-#                 method = "REML")
+
 m_gamm <- su_gamm_univar_4
-# m_gamm   <- gamm(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = su_eg1,
-#                  method = "REML")
+
 m_bam    <- bam(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = su_eg1,
-                method = "fREML")
+  method = "fREML")
+
 m_gamgcv <- gam(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = su_eg1,
-                method = "GCV.Cp")
+  method = "GCV.Cp")
+
 m_gamm4  <- gamm4(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = su_eg1,
-                  REML = TRUE)
+  REML = TRUE)
+m_gamm4_real <- m_gamm4
+  class(m_gamm4_real) <- append("gamm4", class(m_gamm4_real[-1L]))
 
 m_gaulss <- gam(list(y ~ s(x0) + s(x1) + s(x2) + s(x3), ~ 1), data = su_eg1,
                 family = gaulss)
@@ -106,6 +163,7 @@ m_scat <- gam(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = su_eg1,
               family = scat(), method = "REML")
 
 m_lm  <- lm(y ~ x0 + x1 + x2 + x3, data = quick_eg1)
+
 m_glm <- glm(y ~ x0 + x1 + x2 + x3, data = quick_eg1)
 
 # rootogram models
@@ -196,3 +254,36 @@ m_para_sm <- gam(y ~ fac * ff + x0 + s(x1) + s(x2),
 # a GAM with parametric terms (factor and linear) and smooth terms
 m_only_para <- gam(y ~ fac * ff + x0 + x1 + x2,
                    data = df_2_fac, method = "REML")
+
+##-- scam models ---------------------------------------------------------------
+data(smallAges)
+smallAges$Error[1] <- 1.1
+sw <- scam(Date ~ s(Depth, k = 5, bs = "mpd"), data = smallAges,
+  weights = 1 / smallAges$Error, gamma = 1.4)
+
+# this should be folded into data_sim()
+`sim_scam` <- function(n, seed = NULL) {
+      ## sort out the seed
+      if (!exists(".Random.seed", envir = .GlobalEnv, inherits = FALSE)) {
+        runif(1)
+      }
+      if (is.null(seed)) {
+          RNGstate <- get(".Random.seed", envir = .GlobalEnv)
+      }
+      else {
+          R.seed <- get(".Random.seed", envir = .GlobalEnv)
+          set.seed(seed)
+          RNGstate <- structure(seed, kind = as.list(RNGkind()))
+          on.exit(assign(".Random.seed", R.seed, envir = .GlobalEnv))
+      }
+      # from ?scam, first example
+      x1 <- runif(n) * 6 - 3
+      f1 <- 3 * exp(-x1^2) # unconstrained term
+      x2 <- runif(n) * 4 - 1
+      f2 <- exp(4 * x2) / (1 + exp(4 * x2)) # monotone increasing smooth
+      y <- f1 + f2 + rnorm(n) * .5
+      tibble(x1 = x1, x2 = x2, y = y)
+}
+dat <- sim_scam(n = 200, seed = 4)
+## fit model, get results, and plot...
+m_scam <- scam(y ~ s(x1, bs = "cr") + s(x2, bs = "mpi"), data = dat)
